#
# spec file for package polybar
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           polybar
Version:        3.6.3
Release:        bp156.3.8
Summary:        A fast and easy-to-use status bar
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/polybar/polybar
Source:         https://github.com/polybar/polybar/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3.5
BuildRequires:  i3
BuildRequires:  i3-devel
BuildRequires:  libmpdclient-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-Sphinx
BuildRequires:  python3-xml
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(libnl-cli-3.0)
BuildRequires:  pkgconfig(libnl-genl-3.0)
BuildRequires:  pkgconfig(libnl-idiag-3.0)
BuildRequires:  pkgconfig(libnl-nf-3.0)
BuildRequires:  pkgconfig(libnl-route-3.0)
BuildRequires:  pkgconfig(libnl-xfrm-3.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libuv) >= 1.3
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-cursor)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-proto)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xcb-xrm)
DocDir:         %{_datadir}/doc

%description
A fast and easy-to-use status bar for tilling WM

%prep
%setup -q

%build
%cmake

%install
%cmake_install
rm -rf %{buildroot}/%{_docdir}/%{name}/.buildinfo

%files
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions
%dir %{_datadir}/doc/%{name}
%dir %{_datadir}/zsh/
%dir %{_datadir}/zsh/site-functions
%dir %{_sysconfdir}/polybar
%{_bindir}/%{name}
%{_bindir}/%{name}-msg
%{_mandir}/man1/%{name}.1%?ext_man
%{_mandir}/man5/%{name}.5%?ext_man
%{_docdir}/%{name}/*
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/zsh/site-functions/_%{name}
%{_datadir}/zsh/site-functions/_%{name}_msg
%{_sysconfdir}/polybar/config.ini
%{_mandir}/man1/polybar-msg.1%{?ext_man}

%changelog
* Wed Apr  5 2023 Tomas Cech <sleep_walker@opensuse.org>
- Added support for XCursor
* Wed May  4 2022 Mateusz Mielczarek <mateusz.mielczarek2@gmail.com>
- Update to 3.6.3:
  * custom/script: Output clearing when exec-if fails (#2674)
  * internal/battery: poll-interval not working (#2649, #2677)
  * ipc: Polybar failing to open IPC channel after another user already ran polybar, if XDG_RUNTIME_DIR is not set (#2683, #2684)
  * No overlines/underlines being drawn when using offsets (#2685)
  * Update struts (_NET_WM_STRUT_PARTIAL) when hiding the bar (#2702)
  * internal/pulseaudio: Hanging during startup (#2707, #2709)
  * internal/xworkspaces: Updates of _NET_DESKTOP_VIEWPORT being ignored (#2693, #2698)
* Sun May  1 2022 Sebastian Ross <sebastianfross1@gmail.com>
- Added new BuildRequires libmpdclient-devel: build requirement for mpd support
* Fri Apr  8 2022 Mateusz Mielczarek <mateusz.mielczarek2@gmail.com>
- Update to 3.6.2:
  * format-offset being ignored (#2643)
  * Negative struts (margin-bottom, margin-top) being ignored (#2642, #2644)
  * Positioning in awesomeWM (#2651)
  * internal/xworkspaces: The module sometimes crashed polybar when windows were closed. (#2655)
  * Mouseover error when only one cursor is defined (#2656)
  * custom/script: Timing inconsistencies (#2650, first described at #2630)
* Thu Mar 10 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.6.1:
  * Fixed compiler warning in Clang 13 (#2613)
  * Fixed compiler error in GCC 12 (#2616, #2614)
  * Fixed installation of docs when some are not generated
    (man, html...) (#2612)
  * Fix LDFLAGS not being respected (#2619)
  * tray-offset-x, tray-offset-y, offset-x, and offset-y were
    mistakenly capped below at 0 (#2620)
  * custom/script: Polybar shutdown being stalled by hanging script
    (#2621)
  * polybar-msg: Wrong hint when using deprecated hook (#2624)
* Wed Mar  2 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.6.0:
  Breaking:
  * We added the backslash escape character (\) for configuration values. This
    means that the literal backslash character now has special meaning in
    configuration files, therefore if you want to use it in a value as a literal
    backslash, you need to escape it with the backslash escape character. The parser
    logs an error if any unescaped backslashes are found in a value. This affects
    you only if you are using two consecutive backslashes in a config value, which
    will now be interpreted as a single literal backslash. (#2354)
  * We rewrote our formatting tag parser. This shouldn't break anything, if you
    experience any problems, please let us know. The new parser now gives errors for
    certain invalid tags where the old parser would just silently ignore them.
    Adding extra text to the end of a valid tag now produces an error. For example,
    tags like %%{T-a}, %%{T2abc}, %%{rfoo}, and others will now start producing errors.
    This does not affect you unless you are producing your own invalid formatting
    tags (for example in a script).
  * For security reasons, the named pipe at /tmp/polybar_mqueue.<PID> had its
    permission bits changed from 666 to 600 to prevent sending ipc messages to
    polybar processes running under a different user.
  * For details see: https://github.com/polybar/polybar/releases/tag/3.6.0
* Wed Sep 22 2021 Michael Vetter <mvetter@suse.com>
- Update to 3.5.7:
  * The tray mistakenly removed tray icons that did not support
    XEMBED (#2479, #2442)
  * custom/ipc: Only the first appearance of the %%pid%% token was
    replaced (#2500)
* Tue May 25 2021 Michael Vetter <mvetter@suse.com>
- Update to 3.5.6:
  Build:
  * Support building documentation on sphinx 4.0 (#2424)
  Fixed:
  * Tray icons sometimes appears outside of bar (#2430, #1679)
  * Crash in the i3 module (#2416)
* Tue Mar  2 2021 Michael Vetter <mvetter@suse.com>
- Update to 3.5.5:
  * Support older python sphinx versions again (gh#2356)
- Changes from 3.5.4:
  * Wrong text displayed if module text ends with } (gh#2331)
- Changes from 3.5.3:
  * Don't use git when building documentation (gh#2309)
  * Empty color values are no longer treated as invalid and no
    longer produce an error.
- Remove sphinx.patch (See gh#2356)
* Mon Dec 28 2020 Martin Pluskal <mpluskal@suse.com>
- Fix previous changelog entry
- Re-fetch correct sources
* Tue Dec 22 2020 Mateusz Mielczarek <mateusz.mielczarek2@gmail.com>
- Bump to version 3.5.2
- Removed 0%%{?suse_version}
- Removed deprecated packages and add new one
- Removed i3-gaps, add offical package i3
- Add new patch to compile with old version of python3-sphinx (openSUSE 15.1 & openSUSE 15.2)
  * sphinx.patch
* Thu Aug 20 2020 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to version 3.4.3
- Fixes GCC 10 Compilation (gh#2098), see gh#2097
* Fri Feb 28 2020 Mateusz Mielczarek <mateusz.mielczarek2@gmail.com>
- Bump to version 3.4.2
- Fix:
  * internal/i3: Workspace icon map misbehaves for empty icon
  * custom/ipc: Clear content if hook produces no output.
  * renderer:
  - The modules on the right no longer overlap the tray or are shifted out of the bar
  - The gradient when modules are shifted out of the bar (because there is not enough space) is now drawn correctly in all circumstances
  - build: Fixed a compilation issue in gcc10
* Thu Oct 31 2019 Mateusz Mielczarek <mateusz.mielczarek2@gmail.com>
- Removed python2 as dependency (EOL)
* Tue Oct 15 2019 Martin Herkt <9+suse@cirno.systems>
- Use c++_compiler in BuildRequires instead of clang
* Thu Aug 22 2019 Mateusz Mielczarek <mateusz.mielczarek2@gmail.com>
- Bump to version 3.4.0
- Add new dependency: python-Sphinx
* Wed Apr  3 2019 Mateusz Mielczarek <mateusz.mielczarek2@gmail.com>
- Bump to version 3.3.1
- Removed polybar-3.3.0-libtype.patch
* Tue Jan 29 2019 mvetter@suse.com
- Remove `userconfig` argument from make:
  This actually is intended to install the config in the users
  home directory. Not possible here.
* Mon Jan 28 2019 mvetter@suse.com
- Add polybar-3.3.0-libtype.patch:
  Fix usage with our cmake macros
* Fri Jan 25 2019 mateusz.mielczarek2@gmail.com
- Init package
